@@ -12,9 +12,13 @@ from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilit
 from je_web_runner.selenium_utils_wrapper.keys.selenium_keys import Keys
 # utils
 from je_web_runner.utils.executor.action_executor import execute_action
+from je_web_runner.utils.executor.action_executor import execute_files
+from je_web_runner.utils.executor.action_executor import executor
 # test object
 from je_web_runner.utils.test_object.test_object_class import TestObject
 from je_web_runner.utils.test_object.test_object_class import create_test_object
 from je_web_runner.utils.test_object.test_object_class import get_test_object_type_list
 # test record
 from je_web_runner.utils.test_record.test_record_class import test_record_instance
+# generate html
+from je_web_runner.utils.html_report.html_report_generate import generate_html
\ No newline at end of file
